EMbeam
======

``embeam`` is a Python library for for modelling beams and lenses in electron
microscopy.

Setting up embeam
-----------------

For instructions on installing the ``embeam`` library, see the
:ref:`installation_instructions_sec` page.

.. Note for those reading the raw .rst file: see file "docs/INSTALL.rst" for
   instructions on installing the embeam library as well as instructions
   for compiling the documentation of this library.

Learning how to use embeam
--------------------------

For those new to the ``embeam`` library, it is recommended that they take a look
at the :ref:`examples_sec` page, which contains some code examples that show how
one can use the ``embeam`` library. While going through the examples, readers
can consult the :ref:`reference_guide_sec` to understand what each line of code
is doing in each example.
	     
Contents
--------
.. toctree::
   :maxdepth: 6
   :numbered:

   Home <self>
   INSTALL
   Reference <_autosummary/embeam>
   examples
   literature
   license

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
